<?php

namespace Drupal\content_editing_message\Form;

use Drupal\Core\Entity\EntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * The enable/disable form for content editing message entities.
 */
class DisableForm extends EntityConfirmFormBase {

  /**
   * The content editing message entity to enable or disable.
   *
   * @var \Drupal\content_editing_message\ContentEditingMessageInterface
   */
  protected $message;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $this->message = $this->entity;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    if ($this->message->status()) {
      return $this->t('Disable message %label?', ['%label' => $this->message->label()]);
    }

    return $this->t('Enable message %label?', ['%label' => $this->message->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    if ($this->message->status()) {
      return $this->t('Message will not display for this entities when it is disabled.');
    }

    return $this->t('Message will be displayed for this entities when it is enabled.');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return $this->message->toUrl('collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_editing_message_disable_confirm_form';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Toggle enable/disable.
    if ($this->message->status()) {
      $this->message->disable();
    }
    else {
      $this->message->enable();
    }
    $this->message->save();

    $form_state->setRedirect('entity.content_editing_message.collection');
  }

}
